JlOtaPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- JlOtaPlatform
- Implementers
Constructors
- JlOtaPlatform()
- Constructs a JlOtaPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
firmwareUpdate(
String filePath, String uuid, String deviceName, dynamic callBack(int result), {Map? otherParams}) → void -
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ JlOtaPlatform
-
The default instance of JlOtaPlatform to use.
getter/setter pair